@@ -51,7 +51,11 @@ def hours_minutes_seconds(value):
 def seconds_to_hhmmss(seconds):
     hours, seconds = divmod(seconds, 3600)
     minutes, seconds = divmod(seconds, 60)
-    return "{0:02d}:{1:02d}:{2}".format(int(hours), int(minutes), "{0:02.1f}".format(seconds) if seconds % 1 else "{0:02d}".format(int(seconds)))
+    return "{0:02d}:{1:02d}:{2}".format(
+        int(hours),
+        int(minutes),
+        "{0:02.1f}".format(seconds) if seconds % 1 else "{0:02d}".format(int(seconds))
+    )
 
 
 __all__ = [
